require 'installer/role'
require 'installer/common'

class Installer::Role::Console < Installer::Role
  attr_accessor :username, :password, :port, :public_hostname, :master_hostname
  attr_accessor :console_db, :console_auth_db, :puppetdb_db, :smtp

  def initialize(config={})
    super(config)
    @console_auth_db = config[:console_auth_db]
    @console_db = config[:console_db]
    @inbound << {role: :master, port: 443}
    @inbound << {role: :master, port: 8140}
    @master_certname = config[:master_certname]
    @master_hostname = config[:master_hostname]
    @outbound << {role: :master, port: 8140}
    @password = config[:password]
    @port = config[:port] || 443
    @public_hostname = config[:public_hostname]
    @puppetdb_db = config[:puppetdb_db]
    @puppetdb_hostname = config[:puppetdb_hostname]
    @puppetdb_port = config[:puppetdb_port] || 8081
    @requires = [:master, :puppetdb, :smtp]
    @smtp = config[:smtp]
    @username = config[:username]
    @installed_services << "pe-memcached"
    @installed_services << "pe-puppet-dashboard-workers"
  end

  def answers_hash
    hash = super({})
    hash.merge!(
      'q_database_host' => @console_db.hostname,
      'q_database_port' => @console_db.port,
      'q_pe_database' => true_false_to_yn(@console_db.pe_managed),
      'q_public_hostname' => @public_hostname || @host.hostname,
      'q_puppet_enterpriseconsole_auth_database_name' => @console_auth_db.name,
      'q_puppet_enterpriseconsole_auth_database_password' => @console_auth_db.password,
      'q_puppet_enterpriseconsole_auth_database_user' => @console_auth_db.username,
      'q_puppet_enterpriseconsole_auth_password' => @password,
      'q_puppet_enterpriseconsole_auth_user_email' => @username,
      'q_puppet_enterpriseconsole_database_name' => @console_db.name,
      'q_puppet_enterpriseconsole_database_password' => @console_db.password,
      'q_puppet_enterpriseconsole_database_user' => @console_db.username,
      'q_puppet_enterpriseconsole_httpd_port' => @port,
      'q_puppet_enterpriseconsole_install' => 'y',
      'q_puppet_enterpriseconsole_master_hostname' => @master_hostname || @host.hostname,
      'q_puppetdb_database_name' => @puppetdb_db.name,
      'q_puppetdb_database_password' => @puppetdb_db.password,
      'q_puppetdb_database_user' => @puppetdb_db.username,
      'q_puppetdb_hostname' => @puppetdb_hostname,
      'q_puppetdb_port' => @puppetdb_port,
      'q_puppetmaster_certname' => @master_certname
    )
  end

  def name
    :console
  end
end
